@@ -1,7 +1,7 @@
 import logging
 
 from django.db.models import signals
-from django.db import IntegrityError
+from django.db import DatabaseError, IntegrityError
 from django.contrib.auth.models import User
 
 from richtemplates.utils import get_user_profile_model
@@ -17,11 +17,13 @@ def new_richtemplates_profile(instance, **kwargs):
                     user = instance,
                 )
                 logging.debug("New profile created for user %s" % instance)
-            except IntegrityError, err:
+            except (DatabaseError, IntegrityError), err:
                 logging.warning("Richtemplates tried to create profile for new "
-                                "user %s but it seems there is already one. "
+                                "user %s but it seems there is already one or "
+                                "profile table does not exist. "
                                 "Original error: %s" % (instance, err))
-
+                logging.warning("Consider running syncdb again after issue is "
+                                "resolved")
 
 
 def start_listening():
